@@ -73,7 +73,7 @@ def annotate(gen):
 
 
 class _Compiler(object):
-    """Compiles a DOM tree into Intermediate Representation :class:`kajiki.ir.TemplateNode`.
+    """Compiles a DOM tree into IR :class:`kajiki.ir.TemplateNode`.
 
     Intermediate Representation is a tree of nodes that represent
     Python Code that should be generated to execute the template.
@@ -854,7 +854,7 @@ class _DomTransformer(object):
 
     @classmethod
     def _extract_nodes_leading_and_trailing_spaces(cls, tree):
-        """Extract the leading and traling spaces of TextNodes to
+        """Extract the leading and trailing spaces of TextNodes to
         separate nodes.
 
         This is explicitly intended to make i18n easier, as we don't
